@@ -1,4 +1,4 @@
-# (C) Copyright 2020 ECMWF.  #
+# (C) Copyright 2020- ECMWF.  #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
@@ -6,19 +6,29 @@
 # nor does it submit to any jurisdiction.
 #
 
-# This empty __init__.py is there to help find_packages() (in setup.py)
-# to include this folder in the tar uploaded at pip
 
-"""
-Find me
-
-.. autosummary::
-    climetlab.core.Base
-
-"""
+PRIVATE_ATTRIBUTES = {"observer": lambda: None}
 
 
-class Base:
+class MetaBase(type):
+    def __call__(cls, *args, **kwargs):
+        obj = cls.__new__(cls, *args, **kwargs)
+        args, kwargs = cls.patch(obj, *args, **kwargs)
+        obj.__init__(*args, **kwargs)
+        return obj
+
+    def patch(cls, obj, *args, **kwargs):
+        private_attributes = {}
+        private_attributes.update(PRIVATE_ATTRIBUTES)
+        private_attributes.update(kwargs.pop("_PRIVATE_ATTRIBUTES", {}))
+
+        for k, v in private_attributes.items():
+            setattr(obj, k, kwargs.pop(k, v))
+
+        return args, kwargs
+
+
+class Base(metaclass=MetaBase):
 
     # Convertors
     def to_numpy(self, **kwargs):
@@ -41,7 +51,10 @@ class Base:
         return self
 
     # Used when plotting
-    def plot_map(self, driver):
+    def plot_map(self, backend):
+        self._not_implemented()
+
+    def plot_graph(self, backend):
         self._not_implemented()
 
     def field_metadata(self):
