@@ -17,18 +17,19 @@ decide to read it or create it.
 
 """
 
+import ctypes
 import datetime
 import hashlib
 import json
 import logging
 import os
+import platform
 import shutil
 import sqlite3
 import threading
 import time
 from functools import wraps
 
-import psutil
 from filelock import FileLock
 
 from climetlab.core.settings import SETTINGS
@@ -45,6 +46,53 @@ CONNECTION = None
 CACHE = None
 
 
+class DiskUsage:
+    def __init__(self, path):
+
+        path = os.path.realpath(path)
+        self.path = path
+
+        if platform.system() == "Windows":
+            avail = ctypes.c_ulonglong()
+            total = ctypes.c_ulonglong()
+            free = ctypes.c_ulonglong()
+
+            ctypes.windll.kernel32.GetDiskFreeSpaceExW(
+                ctypes.c_wchar_p(path),
+                ctypes.pointer(avail),
+                ctypes.pointer(total),
+                ctypes.pointer(free),
+            )
+            self.avail = avail.value
+            self.total = total.value
+            self.free = free.value
+        else:
+            st = os.statvfs(path)
+            self.free = st.f_bfree * st.f_frsize
+            self.total = st.f_blocks * st.f_frsize
+            self.avail = st.f_bavail * st.f_frsize
+
+        self.percent = int(
+            float(self.total - self.avail) / float(self.total) * 100 + 0.5
+        )
+
+    def __repr__(self):
+        return (
+            f"DiskUsage(total={self.total},free={self.free},"
+            f"avail={self.avail},percent={self.percent},path={self.path})"
+        )
+
+
+def disk_usage(path):
+    return DiskUsage(path)
+
+
+def default_serialiser(o):
+    if isinstance(o, (datetime.date, datetime.datetime)):
+        return o.isoformat()
+    return json.JSONEncoder.default(o)
+
+
 def in_executor(func):
     @wraps(func)
     def wrapped(*args, **kwargs):
@@ -153,6 +201,10 @@ class Cache(threading.Thread):
         cache_directory = SETTINGS.get("cache-directory")
         return path.startswith(cache_directory)
 
+    def _cache_directory(self):
+        cache_directory = SETTINGS.get("cache-directory")
+        return cache_directory
+
     def _ensure_in_cache(self, path):
         assert self._file_in_cache_directory(path), f"File not in cache {path}"
 
@@ -173,17 +225,20 @@ class Cache(threading.Thread):
                     "SELECT MAX(creation_date) FROM cache WHERE size IS NOT NULL"
                 ).fetchone()[0]
             if latest is None:
-                latest = datetime.datetime.utcnow()
+                latest = datetime.datetime.now()
             return latest
 
-    def _purge_cache(self, owner=None, age=None, size=None):
+    def _purge_cache(self, matcher=None):
 
-        if owner is None and age is None and size is None:
-            self._decache(self._cache_size())
+        if matcher is None:
+            self._housekeeping(clean=True)
+            # _update_cache(clean=True)
+            self._decache(self._cache_size(), purge=True)
             return
 
-        with self.connection as db:
-            db.execute("DELETE FROM cache WHERE owner=?", (owner,))
+        dump = self._dump_cache_database(matcher)
+        for entry in dump:
+            self._delete_entry(entry)
 
     def _cache_entries(self):
         result = []
@@ -218,7 +273,7 @@ class Cache(threading.Thread):
                 (
                     size,
                     kind,
-                    json.dumps(owner_data),
+                    json.dumps(owner_data, default=default_serialiser),
                     path,
                 ),
             )
@@ -252,7 +307,7 @@ class Cache(threading.Thread):
             if update or commit:
                 db.commit()
 
-    def _housekeeping(self):
+    def _housekeeping(self, clean=False):
         top = SETTINGS.get("cache-directory")
         with self.connection as db:
             for name in os.listdir(top):
@@ -297,7 +352,7 @@ class Cache(threading.Thread):
                     None,
                     parent,
                 )
-        self._update_cache()
+        self._update_cache(clean=clean)
 
     def _delete_file(self, path):
 
@@ -315,18 +370,21 @@ class Cache(threading.Thread):
         n = dict(entry)
         for k in ("args", "owner_data"):
             if k in n and isinstance(n[k], str):
-                n[k] = json.loads(n[k])
+                try:
+                    n[k] = json.loads(n[k])
+                except Exception:
+                    LOG.debug("Cannot decode JSON %s", n[k])
+                    pass
         return n
 
     def _delete_entry(self, entry):
         if isinstance(entry, str):
             entry = dict(
                 path=entry,
-                size=None,
+                size=0,
                 owner=None,
                 args=None,
             )
-            path, size, owner, args = entry, None, None, None
             try:
                 entry["size"] = os.path.getsize(entry["path"])
             except OSError:
@@ -338,9 +396,14 @@ class Cache(threading.Thread):
             entry["owner"],
             entry["args"],
         )
+        if entry["size"] is None:
+            entry["size"] = 0
 
         LOG.warning(
-            "Deleting entry %s", json.dumps(self._entry_to_dict(entry), indent=4)
+            "Deleting entry %s",
+            json.dumps(
+                self._entry_to_dict(entry), indent=4, default=default_serialiser
+            ),
         )
         total = 0
 
@@ -364,7 +427,7 @@ class Cache(threading.Thread):
 
         return total + size
 
-    def _decache(self, bytes):
+    def _decache(self, bytes, purge=False):
         # _find_orphans()
         # _update_cache(clean=True)
 
@@ -377,7 +440,7 @@ class Cache(threading.Thread):
 
         with self.connection as db:
 
-            latest = self._latest_date()
+            latest = datetime.datetime.now() if purge else self._latest_date()
 
             for stmt in (
                 "SELECT * FROM cache WHERE size IS NOT NULL AND owner='orphans' AND creation_date < ?",
@@ -416,9 +479,9 @@ class Cache(threading.Thread):
 
         with self.connection as db:
 
-            now = datetime.datetime.utcnow()
+            now = datetime.datetime.now()
 
-            args = json.dumps(args)
+            args = json.dumps(args, default=default_serialiser)
 
             db.execute(
                 """
@@ -474,7 +537,7 @@ class Cache(threading.Thread):
         size = self._cache_size()
         usage = SETTINGS.get("maximum-cache-disk-usage")
         cache_directory = SETTINGS.get("cache-directory")
-        df = psutil.disk_usage(cache_directory)
+        df = disk_usage(cache_directory)
         if df.percent > usage:
             LOG.debug("Cache disk usage %s, limit %s", df.percent, usage)
             self._housekeeping()
@@ -503,7 +566,7 @@ class Cache(threading.Thread):
                 html.append("<br>")
         return "".join(html)
 
-    def _dump_cache_database(self):
+    def _dump_cache_database(self, matcher=lambda x: True):
         result = []
         with self.connection as db:
             for d in db.execute("SELECT * FROM cache"):
@@ -511,7 +574,8 @@ class Cache(threading.Thread):
                 for k in ("args", "owner_data"):
                     if n[k] is not None:
                         n[k] = json.loads(n[k])
-                result.append(n)
+                if matcher(n):
+                    result.append(n)
         return result
 
 
@@ -529,6 +593,7 @@ housekeeping = in_executor(CACHE._housekeeping)
 decache_file = in_executor(CACHE._decache_file)
 file_in_cache_directory = in_executor(CACHE._file_in_cache_directory)
 settings_changed = in_executor(CACHE._settings_changed)
+cache_directory = in_executor(CACHE._cache_directory)
 
 
 def cache_file(
@@ -558,7 +623,10 @@ def cache_file(
 
     m = hashlib.sha256()
     m.update(owner.encode("utf-8"))
-    m.update(json.dumps(args, sort_keys=True).encode("utf-8"))
+
+    m.update(
+        json.dumps(args, sort_keys=True, default=default_serialiser).encode("utf-8")
+    )
     m.update(json.dumps(hash_extra, sort_keys=True).encode("utf-8"))
     m.update(json.dumps(extension, sort_keys=True).encode("utf-8"))
 
