@@ -83,7 +83,11 @@ class ZIPReader(ArchiveReader):
 EXTENSIONS_TO_SKIP = (".npz",)  # Numpy arrays
 
 
-def reader(source, path, magic, deeper_check):
+def reader(source, path, magic=None, deeper_check=False):
+
+    if magic is None:  # Bypass check and force
+        return ZIPReader(source, path)
+
     _, extension = os.path.splitext(path)
 
     if magic[:4] == b"PK\x03\x04" and extension not in EXTENSIONS_TO_SKIP:
