@@ -117,7 +117,8 @@ class Variable:
 
 
 class Pattern:
-    def __init__(self, pattern):
+    def __init__(self, pattern, ignore_missing_keys=False):
+        self.ignore_missing_keys = ignore_missing_keys
 
         self.pattern = []
         self.variables = []
@@ -144,6 +145,8 @@ class Pattern:
                 return self._substitute_many(params)
 
         return self._substitute_one(params)
+        # TODO: discuss if this should be:
+        # return [self._substitute_one(params)]
 
     def _substitute_one(self, params):
         used = set(params.keys())
@@ -151,7 +154,7 @@ class Pattern:
         for p in self.pattern:
             used.discard(p.name)
             result.append(p.substitute(params))
-        if used:
+        if used and not self.ignore_missing_keys:
             raise ValueError("Unused parameter(s): {}".format(used))
 
         return "".join(str(x) for x in result)
